uwosh.portaltabssearchbox
=========================

By default, the standard Plone search box is in a viewlet of its own, which
requires vertical space on the page. Similarly, the Plone logo uses vertical
space.

If your site's vertical space is at a premium, you may want to move the search
box into the portal tabs, which by default show links to all items in the root
folder of your site, and hide the logo viewlet.

This product moves the standard Plone search box into the portal tabs viewlet.
